"use Client";

import Link from "next/link";
import React, { useState } from "react";
import { useRouter } from "next/navigation";
import baseRequest from "@/utils/baseRequest";
import { generateSignature } from "@/utils/crypto";
import Image from "next/image";
import platform_wechat from "@/public/images/platform_wechat.png";
import direct_purchase from "@/public/icon/direct_purchase.png";
import app_purchase from "@/public/icon/app_purchase.png";
import { Toast } from "antd-mobile";
import { checkAuth } from "@/utils/auth";

export default function WechatBar({
  price,
  streamerMid,
  auto_response_message,
  onClickDownloadApp,
}) {
  const router = useRouter();
  const [showBuyWechat, setShowBuyWechat] = useState(false);

  const handlePurchase = async () => {
    const isLogined = await checkAuth();
    if (!isLogined) {
      router.push("/auth/login/phonenumlogin");
      return;
    }
    try {
      const base = baseRequest();
      const signature = generateSignature({
        uid: streamerMid,
        pay_type: "alipay_h5",
        ...base,
      });
      const response = await fetch(
        `/api/vas/h5_direct_unlock_wechat?signature=${signature}`,
        {
          method: "POST",
          headers: {
            "Content-Type": "application/json",
          },
          body: JSON.stringify({
            uid: streamerMid,
            pay_type: "alipay_h5",
            ...base,
          }),
        }
      );
      const temData = await response.json();
      if (temData.ret === -1) {
        Toast.show({
          position: "top",
          content: temData.msg,
        });
        return;
      }
      //如果金币够直接付款成功的情况
      if (temData.data.coin_enough === 1) {
        router.push("/purchased");
        return;
      }
      //如果金币不够需要跳转到支付宝付款
      router.push(temData.data.alipay_h5_param_str);
    } catch (error) {
      console.error(error);
    }
  };

  return (
    <div className="flex flex-col mt-8 bg-[#FFFFFF1A] rounded-2xl">
      <div
        onClick={() => setShowBuyWechat(!showBuyWechat)}
        className="flex flex-row cursor-pointer bg-[#07050A] border-2 border-[#FFFFFF26] rounded-2xl h-12 items-center justify-center"
      >
        <Image src={platform_wechat} alt="" className="w-5 h-5" />
        <p className="text-white text-base font-medium ml-2">我的微信</p>
      </div>
      <div
        className={`flex flex-col items-center transition-max-height ease-in-out duration-300 overflow-hidden max-h-0 ${
          showBuyWechat ? "max-h-96" : ""
        }`}
      >
        <div
          className="flex flex-row cursor-pointer items-center justify-center py-4"
          onClick={() => document.getElementById("comfirm_modal").showModal()}
        >
          <Image src={direct_purchase} alt="" className="w-5 h-5" />
          <p className="text-white text-base font-medium ml-2">
            直接解锁(¥{price})
          </p>
        </div>
        <div className="bg-[#FFFFFF26] h-0.5 w-4/5"></div>
        <div
          className="flex flex-row cursor-pointer items-center justify-center py-4 mb-2"
          onClick={() => {
            onClickDownloadApp();
            router.push("/");
          }}
        >
          <Image src={app_purchase} alt="" className="w-5 h-5" />
          <p className="text-white text-base font-medium ml-2">
            APP内解锁(-10%)
          </p>
        </div>
        <div className="bg-[#FFFFFF26] h-0.5 w-4/5"></div>
        <div className="flex flex-row cursor-pointer items-center justify-center py-4 mb-2">
          <pre className="text-white text-base font-medium text-center px-4 ml-2">
            {auto_response_message}
          </pre>
        </div>
      </div>
      <dialog id="comfirm_modal" className="modal">
        <div className="modal-box bg-[#13121F]">
          <p className="text-white text-base font-medium">
            购买成功后请到"账号"-"已购"添加Ta的微信，若超72小时未添加成功请联系客服
          </p>
          <p className="text-secondary text-sm font-medium mt-4 text-center mb-1">
            确认购买即视为同意
            <Link className="link text-primary" href="/doc/rechargeagreement">
              《用户充值协议》
            </Link>
          </p>
          <div className="flex flex-row">
            <button
              className="flex flex-row flex-1 mx-2 items-center justify-center bg-[#FF669E] rounded-lg py-2"
              onClick={handlePurchase}
            >
              <p className="text-white text-base ml-1">立即购买</p>
            </button>
            <form method="dialog" className="flex flex-row flex-1 mx-2">
              <button className="flex flex-row flex-1 items-center justify-center border border-secondary rounded-lg py-2">
                <p className="text-secondary text-base ml-1">取消</p>
              </button>
            </form>
          </div>
        </div>
      </dialog>
    </div>
  );
}
